==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/EquipmentGenerationDetails.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEASSPECIFIC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTPREFIX" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSUFFIX" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCELENGTH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAMPLECODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AUTONUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMISSIONINGWORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INCLUDEPARENTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARENTCODESEPARATOR" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "status",
    "createasspecific",
    "equipmentprefix",
    "equipmentsuffix",
    "sequencelength",
    "samplecode",
    "autonumber",
    "commissioningworkorderid",
    "includeparentcode",
    "parentcodeseparator"
})
@XmlRootElement(name = "EquipmentGenerationDetails")
public class EquipmentGenerationDetails {

    @XmlElement(name = "STATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type status;
    @XmlElement(name = "CREATEASSPECIFIC", namespace = "http://schemas.datastream.net/MP_fields")
    protected String createasspecific;
    @XmlElement(name = "EQUIPMENTPREFIX", namespace = "http://schemas.datastream.net/MP_fields")
    protected String equipmentprefix;
    @XmlElement(name = "EQUIPMENTSUFFIX", namespace = "http://schemas.datastream.net/MP_fields")
    protected String equipmentsuffix;
    @XmlElement(name = "SEQUENCELENGTH", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long sequencelength;
    @XmlElement(name = "SAMPLECODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String samplecode;
    @XmlElement(name = "AUTONUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String autonumber;
    @XmlElement(name = "COMMISSIONINGWORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type commissioningworkorderid;
    @XmlElement(name = "INCLUDEPARENTCODE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String includeparentcode;
    @XmlElement(name = "PARENTCODESEPARATOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected String parentcodeseparator;

    /**
     * Obtient la valeur de la propriété status.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Définit la valeur de la propriété status.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Obtient la valeur de la propriété createasspecific.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCREATEASSPECIFIC() {
        return createasspecific;
    }

    /**
     * Définit la valeur de la propriété createasspecific.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCREATEASSPECIFIC(String value) {
        this.createasspecific = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentprefix.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTPREFIX() {
        return equipmentprefix;
    }

    /**
     * Définit la valeur de la propriété equipmentprefix.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTPREFIX(String value) {
        this.equipmentprefix = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentsuffix.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTSUFFIX() {
        return equipmentsuffix;
    }

    /**
     * Définit la valeur de la propriété equipmentsuffix.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTSUFFIX(String value) {
        this.equipmentsuffix = value;
    }

    /**
     * Obtient la valeur de la propriété sequencelength.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSEQUENCELENGTH() {
        return sequencelength;
    }

    /**
     * Définit la valeur de la propriété sequencelength.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSEQUENCELENGTH(Long value) {
        this.sequencelength = value;
    }

    /**
     * Obtient la valeur de la propriété samplecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSAMPLECODE() {
        return samplecode;
    }

    /**
     * Définit la valeur de la propriété samplecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSAMPLECODE(String value) {
        this.samplecode = value;
    }

    /**
     * Obtient la valeur de la propriété autonumber.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAUTONUMBER() {
        return autonumber;
    }

    /**
     * Définit la valeur de la propriété autonumber.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAUTONUMBER(String value) {
        this.autonumber = value;
    }

    /**
     * Obtient la valeur de la propriété commissioningworkorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getCOMMISSIONINGWORKORDERID() {
        return commissioningworkorderid;
    }

    /**
     * Définit la valeur de la propriété commissioningworkorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setCOMMISSIONINGWORKORDERID(WOID_Type value) {
        this.commissioningworkorderid = value;
    }

    /**
     * Obtient la valeur de la propriété includeparentcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINCLUDEPARENTCODE() {
        return includeparentcode;
    }

    /**
     * Définit la valeur de la propriété includeparentcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINCLUDEPARENTCODE(String value) {
        this.includeparentcode = value;
    }

    /**
     * Obtient la valeur de la propriété parentcodeseparator.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARENTCODESEPARATOR() {
        return parentcodeseparator;
    }

    /**
     * Définit la valeur de la propriété parentcodeseparator.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARENTCODESEPARATOR(String value) {
        this.parentcodeseparator = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/EquipmentGenerationDetails.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEASSPECIFIC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTPREFIX" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSUFFIX" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCELENGTH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAMPLECODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AUTONUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMISSIONINGWORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INCLUDEPARENTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARENTCODESEPARATOR" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "status",
    "createasspecific",
    "equipmentprefix",
    "equipmentsuffix",
    "sequencelength",
    "samplecode",
    "autonumber",
    "commissioningworkorderid",
    "includeparentcode",
    "parentcodeseparator"
})
@XmlRootElement(name = "EquipmentGenerationDetails")
public class EquipmentGenerationDetails {

    @XmlElement(name = "STATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type status;
    @XmlElement(name = "CREATEASSPECIFIC", namespace = "http://schemas.datastream.net/MP_fields")
    protected String createasspecific;
    @XmlElement(name = "EQUIPMENTPREFIX", namespace = "http://schemas.datastream.net/MP_fields")
    protected String equipmentprefix;
    @XmlElement(name = "EQUIPMENTSUFFIX", namespace = "http://schemas.datastream.net/MP_fields")
    protected String equipmentsuffix;
    @XmlElement(name = "SEQUENCELENGTH", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long sequencelength;
    @XmlElement(name = "SAMPLECODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String samplecode;
    @XmlElement(name = "AUTONUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String autonumber;
    @XmlElement(name = "COMMISSIONINGWORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type commissioningworkorderid;
    @XmlElement(name = "INCLUDEPARENTCODE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String includeparentcode;
    @XmlElement(name = "PARENTCODESEPARATOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected String parentcodeseparator;

    /**
     * Gets the value of the status property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Gets the value of the createasspecific property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCREATEASSPECIFIC() {
        return createasspecific;
    }

    /**
     * Sets the value of the createasspecific property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCREATEASSPECIFIC(String value) {
        this.createasspecific = value;
    }

    /**
     * Gets the value of the equipmentprefix property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTPREFIX() {
        return equipmentprefix;
    }

    /**
     * Sets the value of the equipmentprefix property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTPREFIX(String value) {
        this.equipmentprefix = value;
    }

    /**
     * Gets the value of the equipmentsuffix property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTSUFFIX() {
        return equipmentsuffix;
    }

    /**
     * Sets the value of the equipmentsuffix property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTSUFFIX(String value) {
        this.equipmentsuffix = value;
    }

    /**
     * Gets the value of the sequencelength property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSEQUENCELENGTH() {
        return sequencelength;
    }

    /**
     * Sets the value of the sequencelength property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSEQUENCELENGTH(Long value) {
        this.sequencelength = value;
    }

    /**
     * Gets the value of the samplecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSAMPLECODE() {
        return samplecode;
    }

    /**
     * Sets the value of the samplecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSAMPLECODE(String value) {
        this.samplecode = value;
    }

    /**
     * Gets the value of the autonumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAUTONUMBER() {
        return autonumber;
    }

    /**
     * Sets the value of the autonumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAUTONUMBER(String value) {
        this.autonumber = value;
    }

    /**
     * Gets the value of the commissioningworkorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getCOMMISSIONINGWORKORDERID() {
        return commissioningworkorderid;
    }

    /**
     * Sets the value of the commissioningworkorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setCOMMISSIONINGWORKORDERID(WOID_Type value) {
        this.commissioningworkorderid = value;
    }

    /**
     * Gets the value of the includeparentcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINCLUDEPARENTCODE() {
        return includeparentcode;
    }

    /**
     * Sets the value of the includeparentcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINCLUDEPARENTCODE(String value) {
        this.includeparentcode = value;
    }

    /**
     * Gets the value of the parentcodeseparator property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARENTCODESEPARATOR() {
        return parentcodeseparator;
    }

    /**
     * Sets the value of the parentcodeseparator property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARENTCODESEPARATOR(String value) {
        this.parentcodeseparator = value;
    }

}
